@@ -11,6 +11,14 @@ var common = require("../common-tap.js")
 
 var pkg = path.join(__dirname, "prepublish_package")
 
+// TODO: nock uses setImmediate, breaks 0.8: replace with mockRegistry
+if (!global.setImmediate) {
+  global.setImmediate = function () {
+    var args = [arguments[0], 0].concat([].slice.call(arguments, 1))
+    setTimeout.apply(this, args)
+  }
+}
+
 test("setup", function (t) {
   mkdirp(path.join(pkg, "cache"), next)
 
@@ -83,7 +91,7 @@ test("npm publish should honor scoping", function (t) {
   }
 })
 
-test("cleanup", function(t) {
+test("cleanup", function (t) {
   process.chdir(__dirname)
   rimraf(pkg, function (er) {
     t.ifError(er)
